@@ -7,6 +7,7 @@ use Dancer::Plugin::SimpleCRUD;
 simple_crud(
     record_title => 'Person',
     db_table => 'people',
+    db_connection_name => 'foo',
     prefix => '/people',
     acceptable_values => {
         gender => [ qw( Male Female ) ],
@@ -22,6 +23,16 @@ simple_crud(
             label_column => 'name',
         },
     },
+    custom_columns => {
+        mailto_link => {
+            raw_column => 'email',
+            transform  => sub { my $email = shift; return "<a href='mailto:$email'>mail</a>"; },
+        },
+        full_name => {
+            raw_column => "(first_name || ' ' || last_name)",
+            transform => sub { return shift }, # (unnecessary, btw, as this is the default)
+        },
+    },
 );
 
 get '/' => sub {
